@@ -428,21 +428,44 @@ def load_custom_functions_default(start_path: Text = None) -> Dict[Text, Callabl
     try:
         batch_custom_functions = {}
         file_path = os.path.join(start_path, "service")
-        file_path_list = os.listdir(file_path)
-        for i in range(0, len(file_path_list)):
-            path = os.path.join(file_path, file_path_list[i])
-            if os.path.isfile(path):
-                custom_py_name = file_path_list[i].split(".py")[0]
-                # reload to refresh previously loaded module
-                imported_module = importlib.import_module(f"service.{custom_py_name}")
-                batch_custom_functions.update(load_module_functions(imported_module))
-
+        if os.path.exists(file_path):
+            file_path_list = os.listdir(file_path)
+            for i in range(0, len(file_path_list)):
+                path = os.path.join(file_path, file_path_list[i])
+                if os.path.isfile(path):
+                    custom_py_name = file_path_list[i].split(".py")[0]
+                    # reload to refresh previously loaded module
+                    imported_module = importlib.import_module(f"service.{custom_py_name}")
+                    batch_custom_functions.update(load_module_functions(imported_module))
     except Exception as ex:
         logger.error(f"error occurred in custom.py: {ex}")
         sys.exit(1)
     return batch_custom_functions
 
 
+def load_self_functions_default(start_path: Text = None, test_path: Text = None) -> Dict[Text, Callable]:
+    """
+    load project custom module functions
+    """
+    try:
+        separator = "/"
+        if sys.platform.startswith("win"):
+            separator = "\\"
+        if os.path.exists(test_path) and test_path.endswith(".py"):
+            batch_self_functions = {}
+            if start_path[-1] != separator:
+                start_path = start_path + separator
+            self_py_dir = test_path.split(start_path)[1]
+            path = self_py_dir.replace(separator, ".").split(".py")[0]
+            imported_module = importlib.import_module(path)
+            batch_self_functions.update(load_module_functions(imported_module))
+            return batch_self_functions
+    except Exception as ex:
+        logger.error(f"error occurred in {test_path}: {ex}")
+        sys.exit(1)
+    return {}
+
+
 def load_project_meta(test_path: Text, reload: bool = False) -> ProjectMeta:
     """ load testcases, .env, debugtalk.py functions.
         testcases folder is relative to project_root_directory
@@ -500,10 +523,13 @@ def load_project_meta(test_path: Text, reload: bool = False) -> ProjectMeta:
     else:
         custom_functions = {}
 
+    self_functions = load_self_functions_default(project_root_directory, test_path)
+
     # locate project RootDir and load debugtalk.py functions
     project_meta.RootDir = project_root_directory
     project_meta.functions = debugtalk_functions
     project_meta.functions.update(custom_functions)
+    project_meta.functions.update(self_functions)
     project_meta.debugtalk_path = debugtalk_path
     project_meta.custom_path = debugtalk_path
     return project_meta
