@@ -4,7 +4,6 @@ from typing import Union, Text, Dict
 
 import redis
 from loguru import logger
-
 from rrtv_httprunner import exceptions
 
 
@@ -14,8 +13,9 @@ class RedisHandler:
             raise exceptions.DBError("redis datasource not configured")
         driver = driver if isinstance(driver, dict) else eval(driver)
         try:
-            self.r = redis.Redis(host=str(driver["host"]), password=driver["password"], port=int(driver["port"]),
-                                 db=driver["db"])  # 连接redis固定方法,这里的值必须固定写死
+            self.r = redis.Redis(host=str(driver["host"] if "host" in driver else driver["hostName"]),
+                                 password=driver["password"], port=int(driver["port"]),
+                                 db=driver["db"] if "db" in driver else driver["database"])  # 连接redis固定方法,这里的值必须固定写死
         except Exception as e:
             logger.error("redis连接失败，错误信息:%s" % e)
             raise exceptions.DBConnectionError("redis连接失败，错误信息:%s" % e)
