@@ -4,6 +4,7 @@ import itertools
 import json
 import os.path
 import platform
+import sys
 import uuid
 from multiprocessing import Queue
 from typing import Dict, List, Any, Text, NoReturn, Union
@@ -12,7 +13,6 @@ from urllib.parse import quote, unquote
 import pandas as pd
 import sentry_sdk
 from loguru import logger
-
 from rrtv_httprunner import __version__
 from rrtv_httprunner import exceptions
 from rrtv_httprunner.es import ESHandler
@@ -556,7 +556,8 @@ def write_excel(content: Dict, target_dir):
         ugc = pd.read_excel(file, sheet_name=WEB)
     except:
         df = pd.DataFrame(
-            {"所属服务": [], "method": [], "url": [], "name": [], "界面位置": [], "90天是否有调用": [], "curl": []})  # 结构
+            {"所属服务": [], "method": [], "url": [], "name": [], "界面位置": [], "90天是否有调用": [], "response": [],
+             "curl": []})  # 结构
         writer = pd.ExcelWriter(file, engine="openpyxl")
         df.to_excel(writer, sheet_name=APP, index=False)
         df.to_excel(writer, sheet_name=FRIDAY, index=False)
@@ -572,8 +573,7 @@ def write_excel(content: Dict, target_dir):
     tier = get_testcases_tier(content["dir"])
     service = tier[2] if tier[0] == "gateway_api" else ""
     add_data = [service.replace("_", "-"), content["method"], content["url"], content["name"], content["location"],
-                content["call"],
-                content["curl"]]
+                content["call"], content["response"], content["curl"]]
 
     with pd.ExcelWriter(file, mode='a', engine='openpyxl', if_sheet_exists='replace') as writer:
         if "gateway" in tier[0]:
@@ -595,5 +595,9 @@ def get_testcases_tier(dir):
     """
     获取用例层级
     """
-    testcases_after = dir.split("testcases/")[1]
-    return testcases_after.split("/")
+    if sys.platform.startswith("win"):
+        testcases_after = dir.split("testcases\\")[1]
+        return testcases_after.split("\\")
+    else:
+        testcases_after = dir.split("testcases/")[1]
+        return testcases_after.split("/")
